# simple_tracker

[license-image]: https://img.shields.io/npm/l/make-coverage-badge.svg
[license-url]: https://opensource.org/licenses/MIT

[![License][license-image]][license-url]
![Python package](https://github.com/bherbruck/simple_tracker/workflows/Python%20package/badge.svg)

Track multiple objects using just x, y coordinates

## Installation
```bash
$ pip install git+https://github.com/bherbruck/simple_tracker
```